@@ -18,6 +18,9 @@ def resume_pdf(request):
     page_id = request.GET.get("page_id")
     if not page_id:
         return HttpResponseBadRequest("Missing page id for resume generation")
+    if not page_id.isnumeric():
+        return HttpResponseBadRequest("Page id is not a number")
+
     response = HttpResponse(content_type="application/pdf")
     resume = Page.objects.filter(id=page_id).first()
 
